@@ -4,7 +4,7 @@ use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.18_18';
+  our $VERSION = '0.19_01';
 
   use Zydeco
     authority => 'cpan:SMONFF',
@@ -14,6 +14,7 @@ package Art::World {
       'Agent',
       'Artwork',
       'Collector',
+      'Event',
       'Idea',
       'Place',
       'Theory',
@@ -31,9 +32,9 @@ package Art::World {
 
   role Abstraction {
     has discourse ( type => Str );
-    # TODO should only be a table in the database
-    has file! ( type => ArrayRef[ Idea ], );
     has idea! ( type => Str, is => rw,  trigger => true );
+    # BUG if use "imagination" it will always be undef, because it comes alphabetically after "idea" :-/
+    has _imagination ( type => ArrayRef[ Str ] ) = [];
     has process ( type => ArrayRef );
     has project ( type => Str );
     has time ( type => Int );
@@ -43,8 +44,9 @@ package Art::World {
     }
     method insert_to_file {}
     # etc.
+    use DDP;
     method _trigger_idea {
-      push $self->file->@*, $self->idea;
+      push $self->_imagination->@*, $self->idea;
     }
   }
 
@@ -64,16 +66,6 @@ package Art::World {
     }
   }
 
-  role Collective {
-    has members! ( type => ArrayRef[ Object ] );
-    multi method acquire ( Artwork *art, Collective *collective ) {
-      for my $member ( $arg->collective->members->@* ) {
-        $member->pay( $arg->art, $arg->collective );
-      }
-      $arg->art->change_owner( $arg->collective );
-    }
-  }
-
   # Dunno how but the fact of being collected should bump artist reputation
   role Collectionable {
     has owner (
@@ -97,6 +89,8 @@ package Art::World {
         # Or maybe they can... So we should add a specific case
         if (  $meta->get_class( $owner ) !~ '^Art::World::Artist$' ) {
           while ( my ( $i, $art ) = each( $owner->collection->@* )) {
+            # Removing if a matching artwork is found
+            # Should be removed by id, but we don't manage that yet
             if ( $art->title =~ $self->title ) {
               # Wish I would use List::UtilsBy extract_by() for this
               splice $owner->collection->@*, $i, 1;
@@ -128,46 +122,21 @@ package Art::World {
       push $buyers->collection->@*, $self;
       # TODO guess it should bump some people reputation and artwork aura now
     }
-
   }
 
-  role Crud {
-    has dbh! ( type => InstanceOf[ 'Art::World::Model' ], builder => true, lazy => true );
-    has db!  ( type => HashRef[ Str ], builder => true, lazy => true );
+  role Collective {
 
-    method insert ( Str $table, HashRef $attributes ) {
-      # TODO IT MUST BE TESTED
-      unless ( $self->does( 'Art::World::Unserializable' )) {
-        try {
-          my $row = $self->dbh->insert( ucfirst lc $table, $attributes);
-        } catch {
-          cluck 'You tried to insert to ' . $table . ' but this table doesn\'t exist';
-        }
+    has members! ( type => ArrayRef[ Agent ] );
+
+    multi method acquire ( Artwork *art, Collective *collective ) {
+      for my $member ( $arg->collective->members->@* ) {
+        $member->pay( $arg->art, $arg->collective );
       }
-    }
-
-    method _build_dbh {
-      use DBI;
-      use Teng;
-      use Teng::Schema::Loader;
-      my $dbh = Teng::Schema::Loader->load(
-        dbh       => DBI->connect(
-          'dbi:' . $self->db->{ kind } .
-          ':dbname=' . $self->db->{ name },
-          '', '' ),
-        namespace => __PACKAGE__ . '::Model'
-       );
-      return $dbh;
-    }
-
-    method _build_db {
-      return {
-        name => $self->config->{ DB }->{ NAME },
-        kind => $self->config->{ DB }->{ KIND },
-       };
+      $arg->art->change_owner( $arg->collective );
     }
   }
 
+
   role Event {
     has place ( type => Place );
     has datetime ( type => InstanceOf['Time::Moment'] );
@@ -224,18 +193,19 @@ package Art::World {
 
   role Identity {
     has id         ( type => Int );
-    has name!      ( type => Str );
+    has name       ( type => Str );
   }
 
   # From the documentation
   #
-  # A `Place` must `invite()` all kind of `Agents` that produce `Work` or other kind
-  # of valuable social interactions. Depending of the total `reputation` of the
-  # `Place` it will determine it's `underground` status: when going out of the
-  # `underground`, it will become an institution.
+  # A `Place` must `invite()` all kind of `Agents` that produce `Work` or other
+  # kind of valuable social interactions. Depending of the total `reputation` of
+  # the `Place` it will determine it's `underground` status: when going out of
+  # the `underground`, it will become an institution.
   #
   role Invitation {
-    # In case a group of Agents are invited, for an Event like a performance, a concert
+    # In case a group of Agents are invited, for an Event like a performance, a
+    # concert
     multi method invite ( ArrayRef[ Agent ] *people,  Event *event  ) {
     }
   }
@@ -314,7 +284,11 @@ package Art::World {
     # TODO an implemented project (Work, Exhibition) should inherit of this
     # TODO some stuff should extends this
     abstract class Concept {
-      class Idea  with Abstraction { }
+      class Idea  with Abstraction {
+        method express {
+          say $self->discourse if $self->discourse;
+        }
+      }
       class Theory  with Abstraction { }
     }
 
@@ -331,7 +305,8 @@ package Art::World {
     # TODO Guess this is more like an Agent method or role
     class Sex with Event;
 
-    class Playground with Crud, Identity {
+    # Missing some "World" components
+    class Playground with Identity {
 
       class Magazine {
 
@@ -373,16 +348,17 @@ package Art::World {
 
     }
 
-    class Agent with Active, Crud, Fame, Identity {
+    class Agent with Active, Fame, Identity {
 
-      has reputation ( is => rw, type => PositiveOrZeroNum );
+      has relationship;
+      has reputation ( is => rw, type => PositiveOrZeroNum ) = 0;
+      # TODO it would improve a lot the networking
 
       # TODO Should be done during an event
       # TODO In case the networker is a Manager, the reputation bump
       # should be higher
       method networking( ArrayRef $people ) {
 
-        $self->dbh;
         my $highest_reputation = max map { $_-> reputation } $people->@*;
         my $bump = $highest_reputation > 1 ?
           round( $highest_reputation * $self->config->{ FAME }->{ BUMP_COEFFICIENT } / 100) :
@@ -430,6 +406,7 @@ package Art::World {
 
         # factory underground_artist does underground
 
+        # TODO Zydeco already provides a shortcut for this through predicates
         method has_collectors {
           if ( scalar $self->collectors->@* > 1 ) {
             $self->collected( true );
@@ -443,7 +420,8 @@ package Art::World {
           default => sub { [] },
           is      => rw, );
         class Coinvestor with Collective {
-          # TODO the Coinvestor money should be automatically build from all the investors
+          # TODO the Coinvestor money should be automatically build from all the
+          # investors
         }
       }
 
@@ -459,26 +437,27 @@ package Art::World {
         method write( Theory $catalog ) { }
       }
 
-      class Director with Manager;
+      class Director with Manager {
+        class Gallerist {}
+      };
 
       class Public with Unserializable? {
-        method visit {
-          say "I visited";
+        # TODO could have an ArrayRef of Agents attribute
+        method visit( ConsumerOf[ Event ] $event ) {
+          say "I visited " . $event->title;
         }
       }
-      #use Art::Behavior::Crudable;
-      # does Art::Behavior::Crudable;
-      # has relations
     }
 
 
-    class Work extends Concept with Fame {
+    class Work extends Concept with Fame, Identity {
 
       has creation_date;
       has creator!(
         is   => ro,
         type => ArrayRef[ Agent ] );
 
+      # TODO it conflicts a bit with the Identity's name attribute
       has title(
         is   => ro,
         type => Str );
@@ -523,12 +502,11 @@ Art::World - Modeling of creative processes
     creator => [ $artist, $another_artist ]  ,
     owner   => 'smonff'
     title   => 'Corrupted art institutions likes critical art'
-    value   => 100, );
+    value   => 100 );
 
   my $museum = Art::World->new_museum(
     money => 1000,
-    name  => 'Contemporary Museum of Art::World'
-  );
+    name  => 'Contemporary Museum of Art::World' );
 
   $museum->acquire( $artwork );
 
@@ -568,6 +546,9 @@ could be needed in an art galery or a museum.
 This is were all kind of weird phenomenons between abstract artistic entities happen. See the
 L<Manual|Art::World::Manual> about how it works.
 
+Each time an entity got an idea, it's added to the "imagination". Note there is
+also an Idea class.
+
 =head2 Active
 
 Is used to dissociate behaviors belonging to performers as opposed to the
@@ -575,35 +556,52 @@ public. Provide a C<participate> method.
 
 =head2 Buyer
 
-All this behavior and attributes are encapsulated in the C<Buyer> role because
+All those behaviors and attributes are encapsulated in the C<Buyer> role because
 there is no such thing as somebody in the art world that buy but doesn't sale.
 
 The C<aquire> method is requiring some C<money>. The C<money> is provided by the
 C<Market> role.
 
-  $collector->acquire({ art => $artwork });
+  $collector->acquire( $artwork );
 
-Those behaviors are delegated to the private C<$change_owner()> method, and to
+Those behaviors are delegated to the C<change_owner()> method, and to
 the C<pay()> method from the C<Market> role.
 
 When a C<Collector> C<acquire()> an C<Artwork>, the C<Artwork> C<ArrayRef> of
 owners is automatically cleared and substituted by the new owner(s).
 C<acquire()> will remove the value of the C<Artwork> from the owner's money.
 
-  $artwork->change_owner({ buyer => $sef });
+  $artwork->change_owner( $self );
 
 When the paiement occurs, the money is allocated to all the artwork owners
 involved and removed from the buyer's fortune.
 
   $self->pay( $artwork );
 
+It delegate the payment to the C<pay()> method of the C<Market> role. If the
+payment is provided by an individual C<Buyer>, only one payment is done an the
+money is dispatched to all the sellers. If a C<Collective> buy the good, each
+member procede to a paiement from the C<Co-investors> point of view.
+
 =head2 Collectionable
 
-The C<collectionnable> provide a series of attributes.
+The C<collectionnable> provide a series of attributes for the ownership and
+collectionability of artworks.
 
 If it's collectionable, it can go to a C<Collector> collection or in a
 C<Museum>. A collectionable item is automatically owned by it's creator.
 
+C<Collectionable> provides a C<change_owner()> multi method that accepts either
+C<Collectors> or C<Coinvestors> as an unique parameter. It takes care of setting
+appropriately the new artwork owners and delegate the removal of the item from
+the seller's collection.
+
+A private methode, C<$remove_from_seller_collection> is also available to take
+care of the removal of the I<to-be-sold> C<Artwork> in the seller collection.
+Since those can be owned by many persons, and that C<Artists> can own their own
+artworks, but for now cannot be collectors, they are excluded from this
+treatment.
+
 =head2 Collective
 
 They do stuff together. You know, art is not about lonely C<Artists> in their
@@ -616,41 +614,21 @@ This is quite a problem because what if a group of people wants to buy? We have
 a C<Coinvestor> class implementing the C<Collective> role that provide a
 I<collective-acquirement> method.
 
-It's C<acquire()> multi method provide a way to collectively buy an item.
-C<Coinvestor> is a class inheriting from C<Collector> that implement the
-C<Collective> role so it would be able to collectively acquire C<Works>.
+It's C<acquire()> multi method provide a way to collectively buy an item by
+overriding the C<Buyer> role method. C<Coinvestor> is a class
+inheriting from C<Collector> that implement the C<Collective> role so it would
+be able to collectively acquire C<Works>.
 
 Note that the signatures are different between C<Buyer> and C<Collective> roles:
 
-  $collector->acquire({ art => $artwork });
+  $collector->acquire( $artwork );
     # ==> using the method from the Buyer role
 
-  $coinvestors->acquire({ art => $collector->collection->[2], collective => $coinvestors });
+  $coinvestors->acquire({ art => $artwork, collective => $coinvestors });
     # ==> using the method from the Collective role
 
 Just pass a self-reference to the coinvestor object and they will be able to organize and buy together.
 
-=head2 Crud
-
-The C<Crud> role makes possible to serialize most of the entities. For this to be
-possible, they need to have a corresponding table in the database, plus they
-need to not have a C<unserializable?> tag attribute. A Zydeco tag role is a role
-without behavior that can only be checked using C<does>.
-
-The Crud role is made possible thanks to L<Teng>, a simple DBI wrapper and O/R
-Mapper. C<Teng> is used through it's L<schema loader|Teng::Schema::Loader> that
-directly instanciate an object schema from the database.
-
-When trying to update a value, it is necessary to pass a table name and a
-hashref of attributes. The table name is not case sensitive.
-
-Note that it is extremely important that the testing of the database should be
-done in the C<t/crud.t> file. If you want to test database or model
-functionnalities in other tests, remind to create objects by specifiying the
-config parameter that use the C<test.conf> file: only the database referenced in
-C<test.conf> will be available on cpantesters and C<art.db> wont be available there,
-only C<t/test.db> is available.
-
 =head2 Event
 
 All the necessary attributes and methodes for having fun between Art::world's Agents.
@@ -714,15 +692,16 @@ For C<Agents>, C<Places>, etc.
 
 =back
 
-=head2 Market
+=head2 Identity
 
-It is all about offer and demand. Involve C<money>. It provide a C<pay()> method
-that can be using by entities consumming this role. This method accept an
-C<Artwork> as an unique required parameter.
+Provide C<id> and a C<name> attributes.
 
-The C<pay()> method is used by an entity that is designed by C<$self>.
+=head2 Invitation
 
-TODO How many people can buy a thing together?
+=head2 Language
+
+Useful when criticizing art or participating to all kind of events, especially
+fo networking.
 
 =head2 Manager
 
@@ -730,29 +709,56 @@ A role for those who I<take care> of exhibitions and other organizational
 matters. See how being a C<Manager> influence an C<Agent> in the L<CLASSES>
 section.
 
+=head2 Market
+
+It is all about offer, demand and C<money>. It is possible that a day, the
+discourse that some people have can influence the C<Market>.
+
+It provide a C<pay()> method that can be used by entities consumming this role
+to exchange artworks on the market. This method accept an C<Artwork> as an and a
+Collector as parameters. It smartly find how many people bought the good
+and to how many sellers the money should be dispatched.
+
 =head2 Showable
 
 Only an object that does the C<Showable> role can be exhibited. An object should
 be exhibited only if it reached the C<Showable> stage.
 
+=head2 Space
+
+Could limit the number of person attending an event for example
+
+=head2 Underground
+
+Provide an C<experiment()> method.
+
+=head2 Writing
+
+This is much more than small talk.
+
 =head1 CLASSES
 
 =head2 Agent
 
 They are the activists of the Art World, previously known as the I<Wildlife>.
 
-  my $agent = Art::World->new_agent( name => $f->person_name );
+  my $agent = Art::World->new_agent(
+    id         => 1,
+    name       => Art::World::Util->new_person->fake_name,
+    reputation => 10 # Would default to zero if none specified
+  );
 
   $agent->participate;    # ==>  "That's interesting"
 
 A generic entity that can be any activist of the C<Art::World>. Provides all
 kind of C<Agent> classes and roles.
 
-The C<Agent> got an a C<networking( $people )> method. When it is passed and
-C<ArrayRef> of various implementation classes of C<Agents> (C<Artist>,
-C<Curator>, etc.) it bumps the C<reputation> attributes of all of 1/10 of the
-C<Agent> with the highest reputation. If this reputation is less than 1, it is
-rounded to the C<< $self->config->{ FAME }->{ DEFAULT_BUMP } >> constant.
+The C<Agent> got an a C<networking( $people )> method that makes possible to
+leverage it's C<relationships>. When it is passed and C<ArrayRef> of various implementation
+classes of C<Agents> (C<Artist>, C<Curator>, etc.) it bumps the C<reputation>
+attributes of all of 1/10 of the C<Agent> with the highest reputation. If this
+reputation is less than 1, it is rounded to the C<< $self->config->{ FAME }->{
+DEFAULT_BUMP } >> constant.
 
 The bump coefficient can be adjusted in the configuration through C<< { FAME }->{
 BUMP_COEFFICIENT } >>.
@@ -772,6 +778,9 @@ The default values can be edited in C<art.conf>.
 
 Will be what you decide it to be depending on how you combine all the entities.
 
+This is where we are waiting to receive some I<unexpected parameters>: in other
+words, an C<INI> file can be provided.
+
 =head2 Article
 
 Something in a C<Magazine> of C<Website> about C<Art>, C<Exhibitions>, etc.
@@ -803,9 +812,11 @@ When the basic abstractions of Art are articulated, a creation occurs. It
 doesn't mean that it will create an C<Artwork>, because it requires the
 intervention of other C<Agents>. The C<Artist> creates through a work concept.
 This articulation can group the different attributes of the C<Abstraction> role:
-C<discourse>, C<file>, C<idea>, C<process>, C<project> and C<time>.
+C<discourse>, C<imagination>, C<idea>, C<process>, C<project> and C<time>.
 
-=item C<have_idea> all day long
+=item C<have_idea>
+
+All day long
 
 =back
 
@@ -813,28 +824,75 @@ C<discourse>, C<file>, C<idea>, C<process>, C<project> and C<time>.
 
 The base thing producted by artists. Artwork is subclass of
 L<C<Work>|Art::World#Work> that have a C<Showable> and C<Collectionable> role.
+They are usually considered as goods by the C<Market> but are also subject of
+appreciation by the C<Public>. A lot of C<Event> happen around them.
+
+The C<collectionable> role provide their C<value> while they have their own
+attributes for C<material> and C<size>. The later limits the amount of atworks
+that can be put in a C<Place>'s space during an C<Event>.
 
 =head2 Book
 
 Where a lot of theory is written by C<Critics>
 
+=head2 Coinvestor
+
+C<Coinvestor> extend the C<Collector> class by providing an arrayref attribute
+of C<members> through the C<Collective> role. This role makes also possible to
+invest in artworks I<collectively>.
+
 =head2 Collector
 
+A C<Collector> is mostly an C<Agent> that consume the C<Buyer> and C<Market>
+roles and that have a C<collection> attribute.
+
+  my $collector = Art::World
+    ->new_collector(
+      name => Art::World::Util->new_person->fake_name,
+      money => 10_000,
+      id => 4 );
+
+  my $artwork = Art::World
+    ->new_artwork(
+      creator => $artist  ,
+      title   => 'Destroy capitalism',
+      value   => 9_999 );
+
+  $collector->acquire( $artwork ),
+
+  say $collector->money;
+  #==> 1
+
+  say $_->title for ( $collector->collection->@* );
+  #==> Destroy capitalism
+
 =head2 Concept
 
-C<Concept> is an abstract class that does the C<Abstraction> role.
+C<Concept> is an abstract class that does the C<Abstraction> role. It should be
+extended but cannot be instanciated.
 
 =head2 Critic
 
 =head2 Curator
 
 A special kind of Agent that I<can> select Artworks, define a thematic, setup
-everything in the space and write a catalog.
+everything in the space and write a catalog. They mostly do C<Exhibition>.
+
+=head2 Director
 
 =head2 Exhibition
 
 An C<Event> that is organised by a C<Curator>.
 
+  my $exhibition = Art::World->new_exhibition(
+    curator => [ $curator ],
+    title   => $title,
+    creator => [ $curator ]);
+
+=head2 Gallerist
+
+Director of a Gallery
+
 =head2 Gallery
 
 Just another kind of L<C<Place>|Art::World/"Place">, mostly commercial.
@@ -842,9 +900,22 @@ Just another kind of L<C<Place>|Art::World/"Place">, mostly commercial.
 Since it implements the L<C<Buyer>|Art::World/"Buyer"> role, a gallery can both
 C<acquire()> and C<sell()>.
 
+Major place for C<Agent->networking> activities. Always check it's C<space>
+though!
+
 =head2 Idea
 
-When some abstractions starts to become something in the mind of an C<Agent>
+When some abstractions starts to become something in the mind of an C<Agent>.
+
+  my $art_concept = Art::World->new_idea(
+    discourse => 'I have idead. Too many ideas. I store them in a file.',
+    imagination => [ $another_concept, $weird_idea ],
+    idea => 'idea',
+    name => 'Yet Another Idea',
+    process => [],
+    project => 'My project',
+    time => 5,
+   );
 
 =head2 Institution
 
@@ -858,6 +929,17 @@ Yet another kind of C<Place>, an institution with a lot of L<C<Artworks>|Art::Wo
 
 =head2 Opening
 
+An C<Event> where you can consume free treats and speak with other networkers
+from the art world.
+
+  my $t = Art::World::Util->new_time( source => '2020-02-16T08:18:43' );
+  my $opening_event = Art::World->new_opening(
+    place     => $place,
+    datetime => $t->datetime,
+    name => 'Come See Our Stuff',
+    smalltalk => $chat,
+    treat     => [ 'Red wine', 'White wine', 'Peanuts', 'Candies' ]);
+
 =head2 Place
 
 A C<Place> must C<invite()> all kind of C<Agents> that produce C<Work> or other kind
@@ -871,6 +953,8 @@ A generic space where C<Art::World> C<Agents> can do all kind of weird things.
 
 =head2 Public
 
+They participate and visit events.
+
 =head2 School
 
 =head2 Sex
@@ -891,6 +975,10 @@ When some abstract concept turns to some said or written stuff.
 There are not only C<Artworks>. All C<Agent>s produce various kind of work or
 help consuming or implementing C<Art>.
 
+It got an C<aura> attribute, see the L<C<Fame>|Art::World/"Fame"> about it or
+read about L<Walter
+Benjamin|https://en.wikipedia.org/wiki/Walter_Benjamin#%22The_Work_of_Art_in_the_Age_of_Mechanical_Reproduction%22>.
+
 =head2 Workshop
 
 A specific kind of L<C<Playground>|Art::World/"Playground"> where you can build things tranquilly.
